@@ -24,6 +24,7 @@ from weibopy.error import WeibopError
 from PyQt4.QtMaemo5 import QMaemo5InformationBox
 from flickcharm import FlickCharm
 import shutil
+import glob
 
 
 # Define some constants
@@ -165,7 +166,8 @@ class MaoboApp(QApplication):
                 filePath = os.path.join(outbox_path, path)
                 if os.path.isfile(filePath):
                     try:
-                        os.remove(filePath)
+                        for filePath in glob.glob('*.jpg'):
+                            os.remove(filePath)
                     except os.error:
                         continue
  
